Lady Gaga Selfies For Shiseido campaign | Beauty | Grazia Daily
Description: ...and she will also be its photographer.
Keywords: Lady Gaga, Shiseido, campaign, beauty, New Year, 2015, Selfies

Search

# Lady Gaga Took 50 Selfies For New Shiseido Campaign

By Jessica Vince - 29 December 2014

Digital Editor

Lady Gaga out and about in New York City [Getty]

Lady Gaga's no stranger to the world of beauty, having worked on a MAC makeup collection before releasing two of her own fragrances. Now she's dipping her heel into the realm once more as the face of Shiseido's 2015 New Year's ad campaign.

Not only that but Gaga turned her hand to photography for the Japanese beauty brand, shooting the campaign images herself. And yes, that means selfies ahoy!

50 selfies to be exact. According to WWD, the pop star shot a different image for a whooping 50 different Japanese newspapers. And it's no surprise considering selfies have dominated social media in 2014 and there's no doubt Gaga's had plenty of practice - have you seen her selfie-packed Instagram profile? Exactly.

Each image will appear across the New Year's busy shopping period, encouraging shoppers to look as selfie-perfect as Gaga and we have every faith they'll be as wacktacular as ever. Sadly, Shiseido has no plans to publish the campaign outside of Japan but if you'd like to see Gaga's 50 selfies, they're due to be released on the brand's website in the New Year. Failing that, we're sure one or two will pop up on Instagram.

That's a LOT of selfies [Instagram]

### Tags:

Lady Gaga

### Share:

## You May Also Like

### Hot Topics

#### Inside Our Trip To Gstaad With A Small World And Carey Mulligan

### Hot Topics

#### Charli XCX Charts The Soundtrack To Her Life

### Hot Topics

#### CONFIRMED: Keira Knightley Is Pregnant

### Fashion

#### 2014 Best Dressed: Rihanna Did The Trends So You Didn't Have To

### Entertainment

#### Wish You Were Here! See The Stars On Their Festive Breaks

### Fashion

#### Best Dressed: Alexa Chung's Boy-Meets-Girl Wardrobe

powered by DISQUS Read more

#### Disqus

Disqus allows you to post comments on our site. You can only post comments if you register with Disqus and your registration data will be handled in accordance with their privacy policy.

Disqus will use your registration data (email) to send you additional information. Details of how you can opt out are contained in the verification email which you will be sent after you sign up

Please read the Disqus terms of service

Loading...

comments powered by Disqus

## Related Stories

### People

#### Lady Gaga Takes Off Her Wig And Reveals Her REAL Hair

### Beauty

#### Heading for more tropical climates? Prepare yourself with our top 10 best holiday essentials. From mascara that won’t melt in the sun to 8-in-1 bronzing BB cream...

### Fashion

#### Kimye Land First Joint Kampaign For Balmain

## Latest Stories

- ### 2 January 2015 Rosie Huntington Whiteley Goes For A Lob

- ### 31 December 2014 What Donatella Versace Really Thought Of Shooting Madonna Vs Lady Gaga

- ### 22 December 2014 Hairspiration Of The Week: Healthy, Bouncy Curls

- ### 22 December 2014 Kim Kardashian's Hairstylist Has Her Own Tutorial Website

- ### 19 December 2014 We Talk To Blogging Duo Pixiwoo On Their Success And What They're Up To This Christmas

- ### 21 December 2014 The Best Beauty Boxes & Who To Buy Them For

- ### 19 December 2014 We Talk To Blogging Duo Pixiwoo On Their Success And What They're Up To This Christmas

- ### 21 December 2014 The Best Beauty Boxes & Who To Buy Them For

- ### 18 December 2014 Liz Loves... Christmas, Statement Lips And Winter Walks

- ### 18 December 2014 10 Hot Products To Calm Sensitive Skin